==> wine_0.9.25.orig.tar.gz: wine-0.9.25.orig/dlls/olepro32/olepro32stubs.c <==
/*
 * OlePro32 Stubs
 *
 * Copyright 1999 Corel Corporation
 *
 * Sean Langley
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */

#include <stdarg.h>

#include "wine/debug.h"
#include "windef.h"
#include "winbase.h"
#include "winuser.h"
#include "ole2.h"

WINE_DEFAULT_DEBUG_CHANNEL(ole);

/***********************************************************************
 *		DllUnregisterServer (OLEPRO32.258)
 */
HRESULT WINAPI DllUnregisterServer()
{
	FIXME("stub\n");
	return S_OK;
}

/***********************************************************************
 *		DllRegisterServer (OLEPRO32.257)
 */
HRESULT WINAPI DllRegisterServer()
{
	FIXME("stub\n");
	return S_OK;
}

/***********************************************************************
 *		DllCanUnloadNow (OLEPRO32.255)
 */
HRESULT WINAPI DllCanUnloadNow(void)
{
	FIXME("stub\n");
	return S_OK;
}

/***********************************************************************
 *		DllGetClassObject (OLEPRO32.@)
 */
HRESULT WINAPI DllGetClassObject( REFCLSID rclsid, REFIID riid, LPVOID* ppv )
{
	FIXME("stub\n");
	return S_OK;
}

==> wine1.2_1.1.31.orig.tar.gz: wine-1.1.31/dlls/olepro32/olepro32stubs.c <==
/*
 * OlePro32 Stubs
 *
 * Copyright 1999 Corel Corporation
 *
 * Sean Langley
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */

#include <stdarg.h>

#include "wine/debug.h"
#include "windef.h"
#include "winbase.h"
#include "winuser.h"
#include "ole2.h"

WINE_DEFAULT_DEBUG_CHANNEL(ole);

/***********************************************************************
 *		DllUnregisterServer (OLEPRO32.258)
 */
HRESULT WINAPI DllUnregisterServer(void)
{
	FIXME("stub\n");
	return S_OK;
}

/***********************************************************************
 *		DllRegisterServer (OLEPRO32.257)
 */
HRESULT WINAPI DllRegisterServer(void)
{
	FIXME("stub\n");
	return S_OK;
}

/***********************************************************************
 *		DllCanUnloadNow (OLEPRO32.255)
 */
HRESULT WINAPI DllCanUnloadNow(void)
{
	FIXME("stub\n");
	return S_OK;
}

/***********************************************************************
 *		DllGetClassObject (OLEPRO32.@)
 */
HRESULT WINAPI DllGetClassObject( REFCLSID rclsid, REFIID riid, LPVOID* ppv )
{
	FIXME("stub\n");
	return S_OK;
}
